function [tout, yout] = ode1(F,t0,h,tfinal,y0)
% ODE1  A simple ODE solver.
%   [tout,yout] = ODE1(F,t0,h,tfinal,y0) uses Euler's method with fixed 
%   step size h on the interval
%      t0 <= t <= tfinal
%   to solve
%      dy/dt = F(t,y)
%   with y(t0) = y0.
%
% Original (c) 2014 - 2015 The MathWorks, Inc.
% Modified 2022 UWB Pilsen
   
tout = t0 : h : tfinal;  % fixed time steps from t0 to tfinal
tout = tout';  % need a column vector
nt = length(tout);
yout = zeros(nt, length(y0));  % pre-allocation of output

y = y0;  % initial value
yout(1,:) = y'; % the initial value is the first output as well

for k = 1:(nt-1)  % we fill positions 2...nt
    t = tout(k);  % time step t_k
    s = F(t,y);  % function slope
    y = y + h*s;  % value update for the next step
    yout(k+1,:) = y';
end
