function [tout, yout] = ode1i(F,t0,h,tfinal,y0)
% ODE1  A simple implicit ODE solver.
%   [tout,yout] = ODE1(F,t0,h,tfinal,y0) uses implicit Euler's method with fixed 
%   step size h on the interval
%      t0 <= t <= tfinal
%   to solve
%      dy/dt = F(t,y)
%   with y(t0) = y0.
%
% Modified 2022 UWB Pilsen
   
tout = t0 : h : tfinal;  % fixed time steps from t0 to tfinal
nt = length(tout);
yout = zeros(length(y0), nt);  % pre-allocation of output

y = y0;  % initial value
yout(1) = y; % the initial value is the first output as well

for k = 1:(nt-1)  % we fill positions 2...nt
    t = tout(k);  % time step t_k
    y = fzero(@(yi) yi-y-h*F(t+h,yi), y); % value update for the next step
    yout(k+1) = y;
end
