function [tout,yout] = ode2m(F,t0,h,tfinal,y0)
% ODE2M  A simple ODE solver.
%   yout = ODE2M(F,t0,h,tfinal,y0) uses a midpoint
%   rule with fixed step size h on the interval
%      t0 <= t <= tfinal
%   to solve
%      dy/dt = F(t,y)
%   with y(t0) = y0.
%
% Original (c) 2014 - 2015 The MathWorks, Inc.
% Modified 2022 UWB Pilsen

tout = t0 : h : tfinal;  % fixed time steps from t0 to tfinal
nt = length(tout);
yout = zeros(length(y0), nt);  % pre-allocation of output

y = y0;  % initial value
yout(1) = y; % the initial value is the first output as well

h2 = h/2;  % will be used frequently
for k = 1:(nt-1)  % we fill positions 2...nt
    t = tout(k);  % time step t_k
    s1 = F(t,y);  % first estimate of function slope
    s2 = F(t+h2,y+h2*s1); % improved estimate of function slope
    y = y + h*s2;  % value update for the next step
    yout(k+1) = y;
end
